.TH XWSTATICTEXT 3X
.SH NAME
XwstatictextWidgetClass \- An X Widget for displaying static
text.
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/SText.h>
.SH CLASSES
A subclass of CoreClass and XwPrimitiveClass.
.PP
The widget class to use when creating a static text widget
is XwstatictextWidgetClass.
.PP
The class name for StaticText is StaticText.
.SH DESCRIPTION
StaticText provides an uneditable block of text. Optionally
StaticText will provide simple heuristics to fit the text
into arbitrarily sized windows.  Imbedded new-line
characters in the string are always honored.  Stripping of
leading and trailing spaces is optional.
.PP
If the static text widget is directed to become larger than
is needed for the text, the text will be centered in the
window.  The text will retain the specified alignment.
.PP
If the static text widget is directed to become narrower
than is neccessary for the text, the text may be wrapped
(depending on XtNWrap) or clipped to the right and/or left
(depending on the XtNalignment).
.PP
If the static text widget is directed to become shorter than
is neccessary for the text, the text will be clipped on the
bottom.
.PP
When the text is wrapped, StaticText will try to break lines
on spaces.  The space on which the line is broken is
temporarily converted to a newline.
.SH "NEW RESOURCES"
To specify any of these resources within a resource defaults
file, simply drop the XtN prefis from the resource name.
StaticText defines the following new resources:
.IP "" 16
StaticText Resource Set
.ti -18
Name           Class          Type            Default
.br
.ti -18
___________________________________________________________
.br
.ti -18
XtNhSpace      XtCHSpace      int             2
.br
.ti -18
XtNvSpace      XtCVSpace      int             2
.br
.ti -18
XtNalignment   XtCAlignment   XwAlignment     XwALIGN_LEFT
.br
.ti -18
XtNgravity     XtCGravity     int             CenterGravity
.br
.ti -18
XtNwrap        XtCWrap        Boolean         TRUE
.br
.ti -18
XtNstrip       XtCStrip       Boolean         TRUE
.br
.ti -18
XtNlineSpace   XtCLineSpace   int             0
.br
.ti -18
XtNfont        XtCFont        XFontStruct *   Fixed
.br
.ti -18
XtNstring      XtCString      char *          NULL
.br
.TP 5
XtNhSpace
.br
This specifies the number of pixels to maintain between
the text and the highlight area to the right and left
of the text.
.TP 5
XtNvSpace
.br
This specifies the number of pixels to maintain between
the text and the highlight area to the top and bottom
of the text.
.TP 5
XtNalignment
.br
This specifies the alignment to be applied when drawing
the text.  The alignment resource is interpreted
without regard to case.
.IP "" 5
Alignment never causes leading or trailing spaces to be
stripped.
.IP "" 5
Alignment may have the following values and effects:
.IP "" 10
XwALIGN_LEFT will cause the left sides of the
lines will be vertically aligned.  Specified in
resource default file as "Left".
.IP "" 10
XwALIGN_CENTER will cause the centers of the lines
will be vertically aligned.  Specified in resource
default file as "Center".
.IP "" 10
XwALIGN_RIGHT will cause the right sides of the
lines will be vertically aligned.  Specified in
resource default file as "Right".
.TP 5
XtNgravity
.br
This resource controls the use of extra space within
the widget.
.IP "" 10
CenterGravity will cause the string to be centered
in the extra space.  Specified in the resource
defaults file as "CenterGravity".
.IP "" 10
NorthGravity will cause the string to always to be
at the top of the window centered in any extra
width.  Specified in the resource defaults file as
"NorthGravity".
.IP "" 10
SouthGravity will cause the string to always to be
at the bottom of the window centered in any extra
width.  Specified in the resource defaults file as
"SouthGravity".
.IP "" 10
EastGravity will cause the string to always be at
the right of the window centered in any extra
height.  Specified in the resource defaults file
as "EastGravity".
.IP "" 10
WestGravity will cause the string to always be at
the left of the window centered in any extra
height.  Specified in the resource defaults file
as "WestGravity".
.IP "" 10
NorthWestGravity will cause the string to always
be in the upper left corner of the window.
Specified in the resource defaults file as
"NorthWestGravity".
.IP "" 10
NorthEastGravity will cause the string to always
be in the upper right corner of the window.
Specified in the resource defaults file as
"NorthEastGravity".
.IP "" 10
SouthWestGravity will cause the string to always
be in the lower left corner of the window.
Specified in the resource defaults file as
"SouthWestGravity".
.IP "" 10
SouthEastGravity will cause the string to always
be in the lower right corner of the window.
Specified in the resource defaults file as
"SouthEastGravity".
.TP 5
XtNwrap
.br
This resource controls the wrapping of lines within the
widget. If XtNwrap is TRUE, lines which are too long
are broken on spaces.  The spaces are converted to
new-lines to break the line. Imbedded new-lines are
honored.  If there is too much text for the specified
window size, it will be clipped at the bottom.
.IP "" 5
If XtNwrap is FALSE, lines which are too long will be
clipped according to the alignment.  An XtNalignment
value of XwALIGN_LEFT will cause lines which are too
long to be clipped to the right.  An XtNalignment value
of XwALIGN_RIGHT will cause lines which are too long to
be clipped to the left.  An XtNalignment value of
XwALIGN_CENTER will cause lines to be clipped equally
on both the right and the left.
.TP 5
XtNstrip
.br
This resource controls the stripping of leading an
trailing spaces during the layout of the text string.
If XtNstrip is FALSE, spaces are not stripped.  If
XtNstrip is TRUE and XtNalignment is XwALIGN_LEFT,
leading spaces are stripped from each line.  If
XtNstrip is TRUE and XtNalignment is XwALIGN_CENTER,
both leading and trailing spaces are stripped from each
line.  If XtNstrip is TRUE and XtNalignment is
XwALIGN_RIGHT, trailing spaces are stripped from each
line.
.TP 5
XtNlineSpace
.br
This resource controls the amount of space between
lines.  It is specified as a percentage of the font
height.  This space is added between each line of text.
XtNlineSpace may be negative to a maximum of \-100
(which causes all lines to overwrite each other).
.TP 5
XtNfont
.br
This resource controls which font the text will drawn
in.
.TP 5
XtNstring
.br
This resource is the string which will be drawn.  The
string must be null terminated.  If the string is given
in a resource defaults file, newlines may be specified
by "\en" within the string.
.SH "INHERITED RESOURCES"
The following resources are inherited from the indicated
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 10
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.ti -15
Name                    Class                   Type      Default
.br
.ti -15
________________________________________________________________________
.br
.ti -15
XtNforeground           XtCForeground           Pixel     Black
.br
.ti -15
XtNbackgroundTile       XtCBackgroundTile       int       background
.br
.ti -15
XtNtraversalType        XtCTraversalType        int       highlight_off
.br
.ti -15
XtNhighlightStyle       XtCHighlightStyle       int       pattern_border
.br
.ti -15
XtNhighlightColor       XtCForeground           Pixel     Black
.br
.ti -15
XtNhighlightTile        XtCHighlightTile        int       50_foreground
.br
.ti -15
XtNhighlightThickness   XtCHighlightThickness   int       0
.br
.ti -15
XtNrecomputeSize        XtCRecomputeSize        Boolean   TRUE
.br
.ti -15
XtNselect               XtCCallback             Pointer   NULL
.br
.ti -15
XtNrelease              XtCCallback             Pointer   NULL
.br
.SH TRANSLATIONS
The input to the toggle is driven by the mouse buttons.  The
default translation set defining this button is listed
below.  Note that for the specific key symbols used in
traversal, the HP Key Cap which corresponds to this key
symbol appears to the right of the definition.
.IP "" 4
<EnterWindow>:     enter()
.br
<LeaveWindow>:     leave()
.br
<KeyDown>Select:   select()    HP "Select" key
<KeyUp>Select:     release()   HP "Select" key
.SH ACTIONS
.TP 5
enter
.br
If the XtNtraversalType resource has been set to
XwHIGHLIGHT_OFF then the StaticText will be
highlighted.  Otherwise no action is taken.
.TP 5
leave
.br
If the XtNtraversalType resouces has been set to
XwHIGHLIGHT_OFF then the StaticText will be
unhighlighted.  Otherwise no action is taken.
.TP 5
select
.br
Invokes the select callbacks.
.TP 5
release
.br
Invokes the release callbacks.
.SH NOTES
The forced new line is the '\en' character constant as
defined by the C compiler.  Fonts which do not use that
character constant for the newline will not be handled
correctly by StaticText.
.PP
StaticText will assume that the space is the ' ' character
constant as defined by the C compiler.  Fonts which do not
use that character constant for spaces will not be handled
correctly by StaticText.
.PP
Non-8-bit character representations have undefined effects
on the operation of StaticText.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
XWPRIMITIVE(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
